@@ -40,7 +40,7 @@ gameWindow = GameWindow(rootWindow)
 rootWindow.gameWindow = gameWindow
 
 # start the first game
-gameWindow.toolbar.startButton.invoke()
+#gameWindow.toolbar.startButton.invoke()
 
 # run the game
 gameWindow.mainloop()
