@@ -16,5 +16,5 @@
 
 # start running the main program
 
-import dangerUXB
+import DangerUXB
 
